@@ -1,4 +1,4 @@
-from .postgres import PostgresqlStorage
+from .postgres import PostgreSQL
 from .records import Records
 from .schema import Schema
 from .relation import Relation
