@@ -1,22 +1,27 @@
-from typing import Any
 from asyncpg.pool import create_pool as _create_pool, Pool as _Pool
 from asyncpg.connection import Connection as _Connection
 from asyncpg import exceptions as _exceptions
 from loguru._logger import Logger
+from typing import Any
 import loguru
 
 from .schema import Schema
 from .records import Records
 from .types import SchemaType, Record, Instance
-from .baseorm import BaseORM
 
 
-class PostgreSQL(BaseORM):
+class PostgreSQL:
     def __init__(self, database: str,
-                 host: str = 'localhost', port: str | int = 5432,
+                 host: str = 'localhost', port: int | str = 5432,
                  user: str = 'postgres', password: str | None = None,
                  logger: Logger = loguru.logger):
-        super().__init__(database, host, port, user, password, logger)
+        self.database: str = database
+        self.host: str = host
+        self.port: str | int = port
+        self.user: str = user
+        self.password: str | None = password
+
+        self.logger: Logger = logger
 
         self.__pool: _Pool | None = None
         self.__connection: _Connection | None = None
@@ -37,20 +42,20 @@ class PostgreSQL(BaseORM):
             self.logger.error(f'Attempting to close not acquired pool')
         return False
 
-    async def __aenter__(self):
+    async def __aenter__(self) -> _Connection:
         try:
             self.__connection = await self.__pool.acquire()
             return self.__connection
         except AttributeError:
             self.logger.error('Attempting to create connection with not acquired pool')
 
-    async def __aexit__(self, exc_type, exc_val, exc_tb):
+    async def __aexit__(self, exc_type: Any, exc_value: Any, exc_traceback: Any) -> None:
         try:
             await self.__pool.release(self.__connection)
         except _exceptions.InterfaceError:
             self.logger.error('Attempting to release not acquired connection')
 
-    async def execute(self, query: str, args: tuple[Any, ...] = ()) -> Any:
+    async def execute(self, query: str, args: tuple[Any, ...] = ()) -> str:
         async with self as connection:
             return await connection.execute(query, *args)
 
@@ -60,10 +65,9 @@ class PostgreSQL(BaseORM):
         if depth > 0 and schema_t is not dict:
             for index, record in enumerate(records.all()):
                 for relation in record.relations():
-                    columns = ', '.join(relation.columns)
+                    columns, values = ', '.join(relation.columns), tuple(relation.where.values())
                     conditions = ' AND '.join([f'"{key}" = ${index + 1}' for index, key in enumerate(relation.where.keys())])
-                    query, args = f'SELECT {columns} FROM "{relation.tablename}" WHERE {conditions};', tuple(
-                        relation.where.values())
+                    query, args = f'SELECT {columns} FROM "{relation.tablename}" WHERE {conditions};', values
                     instances = (await self.select(query, args, relation.rel_schema_t, depth - 1)).all()
                     if isinstance(record, dict):
                         record[relation.fieldname] = instances
@@ -92,6 +96,8 @@ class PostgreSQL(BaseORM):
         return Records(records, schema_t)
 
     async def delete(self, instance: Instance, schema_t: SchemaType = dict, tablename: str = None) -> Records:
+        # Method successfully removes the instance from the database. Supposed to return the instance and all
+        # related to it instances (children relations), but returns only the instance itself, because of the issue below
         instance, tablename = await self.__parse_parameters(instance, tablename)
         conditions = ' AND '.join([f'"{key}" = ${index + 1}' for index, key in enumerate(instance.keys())])
         query, args = f'SELECT * FROM "{tablename}" WHERE {conditions};', tuple(instance.values())
